/common/ad_asset.proto

--- v16/common/ad_asset.proto   2024-05-29 16:00:42.000000000 +0000
+++ v17/common/ad_asset.proto   2024-05-29 16:00:49.000000000 +0000
@@ -61,6 +61,39 @@
 message AdVideoAsset {
   // The Asset resource name of this video.
   optional string asset = 2;
+
+  // Contains info fields for this AdVideoAsset.
+  optional AdVideoAssetInfo ad_video_asset_info = 4;
+}
+
+// Contains info fields for AdVideoAssets.
+message AdVideoAssetInfo {
+  // List of inventory preferences for this AdVideoAsset. This field can only be
+  // set for DiscoveryVideoResponsiveAd. The video assets with an inventory
+  // asset preference set will be preferred over other videos from the same ad
+  // during serving time. For example, consider this ad being served for a
+  // specific inventory. The server will first try to match an eligible video
+  // with a matching preference for that inventory. Videos with no preferences
+  // are chosen only when a video with matching preference and eligible for a
+  // given ad slot can be found.
+  optional AdVideoAssetInventoryPreferences
+      ad_video_asset_inventory_preferences = 1;
+}
+
+// YouTube Video Asset inventory preferences.
+// Next tag: 4
+message AdVideoAssetInventoryPreferences {
+  // When true, YouTube Video Asset with this inventory preference will be
+  // preferred when choosing a video to serve In Feed.
+  optional bool in_feed_preference = 1;
+
+  // When true, YouTube Video Asset with this inventory preference will be
+  // preferred when choosing a video to serve In Stream.
+  optional bool in_stream_preference = 2;
+
+  // When true, YouTube Video Asset with this inventory preference will be
+  // preferred when choosing a video to serve on YouTube Shorts.
+  optional bool shorts_preference = 3;
 }

 // A media bundle asset used inside an ad.
@@ -69,8 +102,8 @@
   optional string asset = 2;
 }

-// A discovery carousel card asset used inside an ad.
-message AdDiscoveryCarouselCardAsset {
+// A Demand Gen carousel card asset used inside an ad.
+message AdDemandGenCarouselCardAsset {
   // The Asset resource name of this discovery carousel card.
   optional string asset = 1;
 }